﻿using Aml.Equipment.SMD4Api;
using System.Net;

var d = new SMD4();

// Connect the first device found, on any interface
d.Connect();

// Connect the device at this IP address
//d.Connect(ConnectionDescriptor.Build.Ethernet(IPAddress.Parse("10.0.97.70")).Text());


// Connect the first device found on USB
//d.Connect(ConnectionDescriptor.Build.USB().Text());

// Connect device on specific COM port
//d.Connect(ConnectionDescriptor.Build.Serial("COM62",115200));

Console.WriteLine($"Connection:            {d.ConDescriptor}");
Console.WriteLine($"Firmware version:      {d.FirmwareVersion}");
Console.WriteLine($"Product serial number: {d.ProductSerialNumber}");
Console.WriteLine($"Board serial number:   {d.BoardSerialNumber}");
Console.WriteLine($"DHCP:                  {d.DHCP}");
Console.WriteLine($"IP Address:            {d.IP}");

Console.WriteLine();

// Select remote mode to command motor movements remotely
d.Mode = Mode.Remote;

// Clear all error flags
d.Clear();

// Configure step rate and accelerations
d.StepFrequency = 1000;
d.Acceleration = 5000;
d.Deceleration = 5000;

// Configure motor currents
d.AccelerationCurrent = 1;
d.RunCurrent = 1;
d.HoldCurrent = 0;


// Reset step count to 0
d.ActualPosition = 0;                   

// Move CW 1000 steps
int steps = 1000;
Console.WriteLine($"Move {steps} steps");
d.MoveRelative(steps);
d.WaitUntilAtTargetPosition();

// Move -1000 steps
steps = -steps;
Console.WriteLine($"Move {steps} steps");
d.MoveRelative(steps); 
d.WaitUntilAtTargetPosition(0);

// To end up back where we started
if(d.ActualPosition == 0)               
{
    Console.WriteLine("Back at position 0");
}

int i = 10;

var rand = new Random();

// Some relative moves
Console.WriteLine();
Console.WriteLine($"Moving to {i} random absolute positions...");
for (i = 0; i < 10; i++)
{
    int speed = rand.Next(1000, 5000);
    int position = rand.Next(-500, 500);

    Console.WriteLine($"Move {i}, to position {position} at speed {speed} steps per second");
    d.StepFrequency = speed;
    
    // Here we use the optional wait parameter, which causes the method to block until the move has completed
    // Otherwise execution continues and the next move will start before the last has finished
    d.MoveAbsolute(position, waitUntilMoveFinished: true); 
}

Console.WriteLine($"Finished");

Console.WriteLine($"Any key to exit");
Console.ReadKey();